========
aiovault
========


.. image:: https://img.shields.io/pypi/v/aiovault.svg
        :target: https://pypi.python.org/pypi/aiovault

.. image:: https://img.shields.io/travis/terrycain/aiovault.svg
        :target: https://travis-ci.org/terrycain/aiovault

.. image:: https://readthedocs.org/projects/aiovault/badge/?version=latest
        :target: https://aiovault.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

.. image:: https://pyup.io/repos/github/terrycain/aiovault/shield.svg
     :target: https://pyup.io/repos/github/terrycain/aiovault/
     :alt: Updates


Vault asyncio


* Free software: GNU General Public License v3
* Documentation: https://aiovault.readthedocs.io.


Features
--------

* TODO

Credits
---------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage



# TODO
seal_status
initialize

seal_status
is_sealed
seal
unseal

/sys/key-status
rotate
rekey_status
start_rekey
cancel_rekey
rekey
get_backed_up_keys

auth_ app_id tls ec2
